/*
Copyright (c) 1991, 1992, 1993, 1994 Xerox Corporation.  All Rights Reserved.

Unlimited use, reproduction, and distribution of this software is
permitted.  Any copy of this software must include both the above
copyright notice of Xerox Corporation and this paragraph.  Any
distribution of this software must comply with all applicable United
States export control laws.  This software is made available AS IS,
and XEROX CORPORATION DISCLAIMS ALL WARRANTIES, EXPRESS OR IMPLIED,
INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS FOR A PARTICULAR PURPOSE, AND NOTWITHSTANDING ANY OTHER
PROVISION CONTAINED HEREIN, ANY LIABILITY FOR DAMAGES RESULTING FROM
THE SOFTWARE OR ITS USE IS EXPRESSLY DISCLAIMED, WHETHER ARISING IN
CONTRACT, TORT (INCLUDING NEGLIGENCE) OR STRICT LIABILITY, EVEN IF
XEROX CORPORATION IS ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.

$Id: iohcobject.h,v 1.5 1996/07/09 23:10:25 larner Exp $
*/
#ifdef __cplusplus
extern "C" {
#endif

/* IO Handler Closure Object implementation */

typedef struct
{
	PyObject_HEAD
	int		fileno;
	ilu_IOHandler	handler;
	ilu_private	rock;
} IohcObject;

extern PyTypeObject	Iohc_Type;

#define iohc_Check(op)	((op)->ob_type == &Iohc_Type)

extern PyObject *	iohc_New(int fd, ilu_IOHandler handler,
				ilu_private rock);

#ifdef __cplusplus
}
#endif
